@@ -381,10 +381,8 @@ _gdk_pixbuf_new_from_uri_at_scale (const char *uri,
     if (input_stream == NULL) {
         input_stream = gs_file_read_noatime (file, NULL, &error);
         if (input_stream == NULL) {
-            if (error != NULL) {
-                g_warning ("Unable to create an input stream for %s: %s", uri, error->message);
-                g_clear_error (&error);
-            }
+            g_warning ("Unable to create an input stream for %s: %s", uri, error->message);
+            g_clear_error (&error);
 	    g_object_unref (file);
             return NULL;
         }
@@ -400,13 +398,11 @@ _gdk_pixbuf_new_from_uri_at_scale (const char *uri,
 					  sizeof (buffer),
 					  NULL,
 					  &error);
-        if (error != NULL) {
+        if (bytes_read == -1) {
             g_warning ("Error reading from %s: %s", uri, error->message);
             g_clear_error (&error);
+            break;
         }
-	if (bytes_read == -1) {
-	    break;
-	}
 	result = TRUE;
 	if (bytes_read == 0) {
 	    break;
@@ -444,7 +440,11 @@ _gdk_pixbuf_new_from_uri_at_scale (const char *uri,
 	}
     }
 
-    gdk_pixbuf_loader_close (loader, NULL);
+    if (gdk_pixbuf_loader_close (loader, &error) == FALSE) {
+        g_warning ("Error creating thumbnail for %s: %s", uri, error->message);
+        g_clear_error (&error);
+        result = FALSE;
+    }
 
     if (!result) {
 	g_object_unref (G_OBJECT (loader));
